Index: src/isolate.h |
diff --git a/src/isolate.h b/src/isolate.h |
index f6544597f25dae4714af2a6c53e3fac891965245..3d0a9c0e0d6509ef07adda523ed7f8e6402ba716 100644 |
--- a/src/isolate.h |
+++ b/src/isolate.h |
@@ -764,8 +764,9 @@ class Isolate { |
void IterateThread(ThreadVisitor* v, char* t); |
// Returns the current native context. |
Handle<Context> native_context(); |
+ Handle<Context> global_context(); |
// Returns the native context of the calling JavaScript code. That |
// is, the native context of the top-most JavaScript frame. |
@@ -764,8 +764,9 @@ class Isolate { |
void IterateThread(ThreadVisitor* v, char* t); |
- // Returns the current native context. |
+ // Returns the current native and global context. |
Handle<Context> native_context(); |